@ECHO OFF
REM 
::*********************************************************************************
::************************ Club Hub Installer Package *****************************
::*********************************************************************************
:: Performs the following tasks in order:
:: - Gets GUID and Install Code from user
:: - Stops Check-In
:: - Checks the Operating System info
:: - Restarts Check-In
:: - Displays the OS info for user and prompts to proceed with install
:: - Installs applications in the following order:
:: ----= Visual FoxPro
:: ----= .NET 4.0 Framework
:: ----= Club Hub Door Service
:: ----= SQL Compact 4
:: - Executes Check-In --> Club Hub data import process
:: - Configures Door Service, re-syncs time, starts Door Service
:: - If necessary, launches Kaseya installer
:: - Prompts user to complete installation and launch the Club Hub application
:: - Configures power settings and then closes the Batch Installer
::*****************************************************************************************



REM -- Set flag for OS bit level ( 0=32bit, 1=64bit ) --
SET bit=0 
REM -- Set the absolute PATH for installation package location --
SET location=C:\ClubHub\ClubHubInstaller

DEL "C:\ClubHub\ClubHubInstaller.zip"


IF EXIST "C:\ClubHub\" ( 
GOTO next 
) ELSE ( 
MKDIR "C:\ClubHub"
ECHO - >> "C:\ClubHub\conversionLog.txt" 
)

:next
IF NOT EXIST "%location%\start.log" ( GOTO noBatStart )

ECHO ----
IF EXIST "%location%\australia.txt" ( ECHO Country Code: AUSTRALIA 
) ELSE IF EXIST "%location%\netherlands.txt" ( ECHO Country Code: NETHERLANDS
) ELSE ( ECHO Country Code: USA )


TITLE Club Hub Package Installer


ECHO -------------------------------------------- >> "C:\ClubHub\conversionLog.txt"
ECHO ---------- Club Hub Installer Log ---------- >> "C:\ClubHub\conversionLog.txt"
ECHO -------------------------------------------- >> "C:\ClubHub\conversionLog.txt"


"%location%\Application\getDateTime.exe" >> "C:\ClubHub\conversionLog.txt"
ECHO System status checks complete
ECHO System status checks complete >> "C:\ClubHub\conversionLog.txt"
ECHO ----


:stepOne


:getCodesFromUser
REM ---- Prompt the user to enter in the club's GUID and Door Service Install code ----
"%location%\Application\getDateTime.exe" >> "C:\ClubHub\conversionLog.txt"
REM ECHO No GUID or Install Code file was found
REM ECHO GUID and Install Code manually entered >> "C:\ClubHub\conversionLog.txt"
REM ECHO ----
REM ECHO Enter the Club GUID:
REM SET /P guid=[promptString]
ECHO Enter the Door Service Install Code (leave blank if not required):
SET /P install=[promptString]
ECHO ----
REM ECHO GUID set to: %guid% >> "C:\ClubHub\conversionLog.txt"
ECHO INSTALL CODE set to: %install% >> "C:\ClubHub\conversionLog.txt"
REM ===================================================================================


:begin
REM IF NOT DEFINED guid ( 
REM ECHO No GUID was entered 
REM ECHO No GUID was entered >> "C:\ClubHub\conversionLog.txt"
REM )
IF NOT DEFINED install ( 
ECHO No INSTALL CODE was entered >> "C:\ClubHub\conversionLog.txt"
)


REM ---- Prompt the user to choose if Check-In should be shut down so stav can be activated ----
ECHO ----
"%location%\Application\getDateTime.exe" >> "C:\ClubHub\conversionLog.txt"
ECHO Serial port and index information is required
ECHO Gathering serial port and index information if required >> "C:\ClubHub\conversionLog.txt"
ECHO ---- 
"%location%\Application\Choice.exe"




REM ------------ CHECK TO SEE WHICH VERSION OF WINDOWS IS RUNNING -------------------
:checkOS
ECHO ----
ECHO Checking if OS is 64 or 32 bit
ECHO Checking if OS is 64 or 32 bit >> "C:\ClubHub\conversionLog.txt"
ver | find "XP" > nul
IF %ERRORLEVEL% == 0 GOTO ver_xp
GOTO ver_7
REM ==================================================================================




REM *************************************************************************************************
REM ************ IF RUNNING WINDOWS 7 or newer PROCEED WITH THE FOLLOWING STEPS *********************
REM *************************************************************************************************
:ver_7
IF EXIST "C:\Windows\SysWOW64\cmd.exe" SET bit=1

IF /I  %bit% == 1 ( 
ECHO Detected Operating System is 64 bit
ECHO Detected Operating System is 64 bit >> "C:\ClubHub\conversionLog.txt"
)
IF /I  %bit% == 0 (
ECHO Detected Operating System is 32 bit 
ECHO Detected Operating System is 32 bit >> "C:\ClubHub\conversionLog.txt"
)
ECHO ----
"%location%\Application\getDateTime.exe" >> "C:\ClubHub\conversionLog.txt"
ECHO Configuring system power settings... >> "C:\ClubHub\conversionLog.txt"
ECHO Configuring system power settings...
REM change power settings
REM create new scheme, export scheme, import scheme alternative method
POWERCFG -DUPLICATESCHEME 381b4222-f694-41f0-9685-ff5bb260df2e 381b4222-f694-41f0-9685-ff5bb260aaaa
POWERCFG -CHANGENAME 381b4222-f694-41f0-9685-ff5bb260aaaa "Anytime"
POWERCFG -SETACTIVE 381b4222-f694-41f0-9685-ff5bb260aaaa
POWERCFG -CHANGE -monitor-timeout-ac 0
POWERCFG -CHANGE -monitor-timeout-dc 0
POWERCFG -CHANGE -disk-timeout-ac 0
POWERCFG -CHANGE -disk-timeout-dc 0
POWERCFG -CHANGE -standby-timeout-ac 0
POWERCFG -CHANGE -standby-timeout-dc 0
POWERCFG -CHANGE -hibernate-timeout-ac 0
POWERCFG -CHANGE -hibernate-timeout-dc 0
POWERCFG -SETDCVALUEINDEX 381b4222-f694-41f0-9685-ff5bb260aaaa SUB_NONE CONSOLELOCK 0
POWERCFG -SETACVALUEINDEX 381b4222-f694-41f0-9685-ff5bb260aaaa SUB_NONE CONSOLELOCK 0
ECHO power settings applied
ECHO ----

DEL "C:\Users\%username%\Desktop\Ionic.Zip.dll"

REM ------------------ SET THE DIRECTORY/FILE PERMISSIONS -------------------------
"%location%\Application\getDateTime.exe" >> "C:\ClubHub\conversionLog.txt"
ECHO Setting Directory and File permissions >> "C:\ClubHub\conversionLog.txt"
ECHO Setting Directory and File permissions...
IF EXIST "C:\Windows\SysWOW64\cmd.exe" (
	CACLS "C:\Program Files (x86)\Anytime Fitness" /t /e /c /p "%USERNAME%":F
	) ELSE (
	CACLS "C:\Program Files\Anytime Fitness" /t /e /c /p "%USERNAME%":F
	)
IF EXIST "C:\Windows\SysWOW64\cmd.exe" (
	CACLS "C:\Windows\SysWOW64\config\systemprofile\AppData\Local\Anytime_Fitness" /t /e /c /p "%USERNAME%":F
	) ELSE (
	CACLS "C:\Windows\System32\config\systemprofile\AppData\Local\Anytime_Fitness" /t /e /c /p "%USERNAME%":F
	)
CACLS "C:\Users\%USERNAME%\AppData\Local\Apps" /t /e /c /p "%USERNAME%":F
CACLS C:\ClubHub /t /e /c /p "%USERNAME%":F
ECHO ----
ECHO Permissions set
ECHO ----
REM ===============================================================================	
		

:ndShortStart7
REM -------------- Configure URL reservation --------------------------------------
"%location%\Application\getDateTime.exe" >> "C:\ClubHub\conversionLog.txt"
ECHO ----
ECHO Attempting to set URL ACL reservation...
ECHO Attempting to set URL reservation >> "C:\ClubHub\conversionLog.txt"
netsh http add urlacl url=http://+:9090/ user="%USERNAME%"
REM ======================================================================


cd /d "%location%"
ECHO ----
ECHO Preparing software package for installation...
ECHO ----
"%location%\Application\getDateTime.exe" >> "C:\ClubHub\conversionLog.txt"
ECHO Installing software package... >> "C:\ClubHub\conversionLog.txt"

ECHO ----

REM ---------------------- Install Door Service -------------------
"%location%\Application\getDateTime.exe" >> "C:\ClubHub\conversionLog.txt"
ECHO Installing Club Hub Door Service if required >> "C:\ClubHub\conversionLog.txt"
ECHO Installing Club Hub Door Service...
IF /I %bit% == 0 (
IF NOT EXIST "C:\Program Files\Anytime Fitness\ClubHub DoorService\ClubHub.Club.DoorService.Core.dll" ( "%location%"\Installer\setup.exe /passive
) ELSE ( ECHO Door Service already installed )
)

IF /I %bit% == 1 (
IF NOT EXIST "C:\Program Files (x86)\Anytime Fitness\ClubHub DoorService\ClubHub.Club.DoorService.Core.dll" ( "%location%"\Installer\setup.exe /passive
) ELSE ( ECHO Door Service already installed )
)
REM =====================================================================

ECHO ----

REM ------------------------ Install SQL Compact ------------------------------
"%location%\Application\getDateTime.exe" >> "C:\ClubHub\conversionLog.txt"
ECHO Installing Microsoft SQL Compact 4.0 if required >> "C:\ClubHub\conversionLog.txt"
ECHO Installing Microsoft SQL Compact 4.0...
IF /I  %bit% == 0 (
IF NOT EXIST "C:\Program Files\Microsoft SQL Server Compact Edition\v4.0\REDIST_ENU.txt" ( "%location%"\Runtimes\x86\SSCERuntime_x86-ENU.exe /i /quiet 
) ELSE ( ECHO SQL Compact 4 is already installed )
)
IF /I %bit% == 1 (
IF NOT EXIST "C:\Program Files (x86)\Microsoft SQL Server Compact Edition\v4.0\REDIST_ENU.txt" ( "%location%"\Runtimes\x64\SSCERuntime_x64-ENU.exe /i /quiet 
) ELSE ( ECHO SQL Compact 4 is already installed )
)
REM ===============================================================================

ECHO ----
ECHO ----


REM ----------------- Install Door Service code in Registry --------------------------------------
"%location%\Application\getDateTime.exe" >> "C:\ClubHub\conversionLog.txt"
ECHO Setting Install Code and Configuring System Services >> "C:\ClubHub\conversionLog.txt"
ECHO Setting Install Code and Configuring System Services...
IF /I  %bit% == 0 (
IF DEFINED install ( reg add HKEY_LOCAL_MACHINE\SOFTWARE\ClubHub /v InstallCode /t REG_SZ /d %install% /f
) ELSE ( ECHO No Install code was defined - The REGISTRY entry will not be modified )
)

IF /I %bit% == 1 (
IF DEFINED install ( reg add HKEY_LOCAL_MACHINE\SOFTWARE\Wow6432Node\ClubHub /v InstallCode /t REG_SZ /d %install% /f
) ELSE ( ECHO No Install code was defined - The REGISTRY entry will not be modified )
)
REM ==================================================================================



REM ------------------ Configure Door Service and update to latest Version ------------------------------
ECHO ----
ECHO Configuring Door Service...
sc config "DoorService" start= auto
sc failure "DoorService" reset= 3600 actions= restart/5000/restart/10000/restart/60000
sc config "DoorService" depend= winmgmt
ECHO Door Service configured
ECHO ----

ECHO Updating Door Service...
IF /I %bit% == 1 (
XCOPY "%location%"\Resources\DoorService "C:\Program Files (x86)\Anytime Fitness\ClubHub DoorService" /Y
) ELSE ( XCOPY "%location%"\Resources\DoorService "C:\Program Files\Anytime Fitness\ClubHub DoorService" /Y)
)
ECHO Door Service update complete
ECHO ----
REM ==================================================================================================



REM ================ Installing Certificates for Club Hub client =========================
ECHO Installing client certificates...
ECHO Installing client certificates >> "C:\ClubHub\conversionLog.txt"
"%location%"\Resources\certmgr.exe /add /c "%location%"\Resources\ClubHubCert.cer /s /r localMachine TrustedPublisher
"%location%"\Resources\certmgr.exe /add /c "%location%"\Resources\ClubHubCert.cer /s /r localMachine root
ECHO ----
REM ======================================================================================

"%location%\Application\getDateTime.exe" >> "C:\ClubHub\conversionLog.txt"
ECHO Data Import Complete
ECHO Ready to launch Club Hub
ECHO Launching Club Hub UI installer >> "C:\ClubHub\conversionLog.txt"
ECHO ---- >> "C:\ClubHub\conversionLog.txt"
"%location%"\Application\setupProduction.exe

IF DEFINED install ( net start "Anytime Fitness Door Service" )

REM ---------------------  Set Firewall --------------------------------------------------------------------------
"%location%\Application\getDateTime.exe" >> "C:\ClubHub\conversionLog.txt"
ECHO Configuring Firewall...
ECHO Configuring Firewall >> "C:\ClubHub\conversionLog.txt"
netsh advfirewall firewall add rule name="Club Hub TCP 13" dir=in action=allow protocol=TCP localport=13
netsh advfirewall firewall add rule name="Club Hub TCP 139" dir=in action=allow protocol=TCP localport=139
netsh advfirewall firewall add rule name="Club Hub TCP 9000" dir=in action=allow protocol=TCP localport=9000
netsh advfirewall firewall add rule name="Club Hub TCP 9090" dir=in action=allow protocol=TCP localport=9090

netsh advfirewall firewall add rule name="Club Hub UDP 123" dir=in action=allow protocol=UDP localport=123
netsh advfirewall firewall add rule name="Club Hub UDP 137" dir=in action=allow protocol=UDP localport=137
netsh advfirewall firewall add rule name="Club Hub UDP 138" dir=in action=allow protocol=UDP localport=138

netsh advfirewall firewall add rule name="Club Hub TCP 13" dir=out action=allow protocol=TCP localport=13
netsh advfirewall firewall add rule name="Club Hub TCP 139" dir=out action=allow protocol=TCP localport=139
netsh advfirewall firewall add rule name="Club Hub TCP 9000" dir=out action=allow protocol=TCP localport=9000
netsh advfirewall firewall add rule name="Club Hub TCP 9090" dir=out action=allow protocol=TCP localport=9090

netsh advfirewall firewall add rule name="Club Hub UDP 123" dir=out action=allow protocol=UDP localport=123
netsh advfirewall firewall add rule name="Club Hub UDP 137" dir=out action=allow protocol=UDP localport=137
netsh advfirewall firewall add rule name="Club Hub UDP 139" dir=out action=allow protocol=UDP localport=138

netsh advfirewall firewall add rule name="Door Service TCP 3306" dir=out action=allow protocol=TCP localport=3306
netsh advfirewall firewall add rule name="Door Service TCP 3306" dir=in action=allow protocol=TCP localport=3306
REM ================================================================================================================

REM ---------------------------- Delete Package Files -----------------------------------------
"%location%\Application\getDateTime.exe" >> "C:\ClubHub\conversionLog.txt"
ECHO Performing clean up operation...
ECHO Cleaning up package files >> "C:\ClubHub\conversionLog.txt"
DEL /F /Q "C:\ClubHub\ClubHubInstaller\Application"
DEL /F /Q "C:\ClubHub\ClubHubInstaller\ConsoleImporter"
DEL /F /Q "C:\ClubHub\ClubHubInstaller\Installer"
DEL /F /Q "C:\ClubHub\ClubHubInstaller\Resources"
DEL /F /Q "C:\ClubHub\ClubHubInstaller\Runtimes"
DEL /F /Q "C:\ClubHub\ClubHubInstaller\Antivirus Exclusion Directories.txt"
DEL /F /Q "C:\ClubHub\ClubHubInstaller\Installer.exe"
DEL /F /Q "C:\ClubHub\ClubHubInstaller\Start.txt"

REM ============================================================================================

"%location%\Application\getDateTime.exe" >> "C:\ClubHub\conversionLog.txt"
ECHO Club Hub Package Installer has completed >> "C:\ClubHub\conversionLog.txt"

EXIT
REM ======================= END OF WINDOWS 7 BATCH =====================================================================================================







REM ****************************************************************************************
:: ************ IF RUNNING WINDOWS XP PROCEED WITH THE FOLLOWING STEPS *********************
REM ****************************************************************************************
:ver_xp
ECHO Detected Operating System is XP
ECHO Detected Operating System is XP >> "C:\ClubHub\conversionLog.txt"
ECHO ---- 

REM change power settings
"%location%\Application\getDateTime.exe" >> "C:\ClubHub\conversionLog.txt"
ECHO Configuring system power settings... >> "C:\ClubHub\conversionLog.txt"
ECHO Configuring system power settings...
POWERCFG /CREATE Anytime
POWERCFG /CHANGE Anytime /monitor-timeout-ac 0
POWERCFG /CHANGE Anytime /monitor-timeout-dc 0
POWERCFG /CHANGE Anytime /disk-timeout-ac 0
POWERCFG /CHANGE Anytime /disk-timeout-dc 0
POWERCFG /CHANGE Anytime /standby-timeout-ac 0
POWERCFG /CHANGE Anytime /standby-timeout-dc 0
POWERCFG /CHANGE Anytime /hibernate-timeout-ac 0
POWERCFG /CHANGE Anytime /hibernate-timeout-dc 0
POWERCFG /CHANGE Anytime /processor-throttle-ac ADAPTIVE
POWERCFG /CHANGE Anytime /processor-throttle-dc ADAPTIVE
POWERCFG /HIBERNATE OFF
POWERCFG /GLOBALPOWERFLAG OFF /OPTION RESUMEPASSWORD
POWERCFG /SETACTIVE Anytime
ECHO power settings applied
ECHO ----

DEL "C:\Documents and Settings\%username%\Desktop\Ionic.Zip.dll"

REM ---------------------------- SET THE DIRECTORY/FILE PERMISSIONS -----------------------------------------
REM turn simple file sharing off
ECHO Turning off Simple File Sharing
reg add "HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Control\Lsa" /v forceguest /t REG_DWORD /d 00000000 /f
REM set security permissions
ECHO ----
"%location%\Application\getDateTime.exe" >> "C:\ClubHub\conversionLog.txt"
ECHO Setting Directory and File permissions >> "C:\ClubHub\conversionLog.txt"
ECHO Setting Directory and File permissions...
CACLS "C:\Program Files\Anytime Fitness" /t /e /c /p "%USERNAME%":F
CACLS "C:\Documents and Settings\%USERPROFILE%\Local Settings\Apps" /t /e /c /p "%USERNAME%":F
CACLS C:\ClubHub /t /e /c /p "%USERNAME%":F
ATTRIB -r -a -h C:\ClubHub /s /d
ATTRIB -r -a -h "C:\Program Files\Anytime Fitness" /s /d
ATTRIB -r -a -h "C:\Documents and Settings\%USERPROFILE%\Local Settings\Apps" /s /d
ECHO Permissions set
ECHO ----
REM ==========================================================================================================	

:ndShortStartXP

:noRestartXP
cd /d "%location%"
"%location%\Application\getDateTime.exe" >> "C:\ClubHub\conversionLog.txt"
ECHO Installing software package... >> "C:\ClubHub\conversionLog.txt"
ECHO ----
ECHO Preparing software package for installation...
ECHO ----
ECHO ----

REM -- Install Door Service -------------------
"%location%\Application\getDateTime.exe" >> "C:\ClubHub\conversionLog.txt"
ECHO Installing Club Hub Door Service... >> "C:\ClubHub\conversionLog.txt"
ECHO Installing Club Hub Door Service...
IF NOT EXIST "C:\Program Files\Anytime Fitness\ClubHub DoorService\ClubHub.Club.DoorService.Core.dll" ( Installer\setup.exe /norestart /quiet
) ELSE ( ECHO Door Service already installed )
REM ============================================

ECHO ----

REM -- Install SQL Compact ------------------------------
"%location%\Application\getDateTime.exe" >> "C:\ClubHub\conversionLog.txt"
ECHO Installing Microsoft Compact SQL Server 4.0... >> "C:\ClubHub\conversionLog.txt"
ECHO Installing Microsoft Compact SQL Server 4.0...
IF NOT EXIST "C:\Program Files\Microsoft SQL Server Compact Edition\v4.0\REDIST_ENU.txt" ( Runtimes\x86\SSCERuntime_x86-ENU.exe /i /quiet 
) ELSE ( ECHO SQL Compact 4 is already installed )
REM ====================================================

ECHO ----


REM -- Install Door Service code in Registry --------------------------------------
"%location%\Application\getDateTime.exe" >> "C:\ClubHub\conversionLog.txt"
ECHO Setting Install Code and Configuring System Services...
ECHO Setting Install Code and Configuring System Services... >> "C:\ClubHub\conversionLog.txt"
IF DEFINED install ( reg add HKEY_LOCAL_MACHINE\SOFTWARE\ClubHub /v InstallCode /t REG_SZ /d %install% /f
) ELSE ( ECHO No Install code was defined - The REGISTRY entry will not be modified )
)
REM ==================================================================================


REM ---------------- Configure Door Service and update to latest version -----------------------------
ECHO ----
ECHO Configuring Door Service...
sc config "DoorService" start= auto
sc failure "DoorService" reset= 3600 actions= restart/5000/restart/10000/restart/60000
sc config "DoorService" depend= winmgmt
ECHO Door Service configured
ECHO ----

ECHO Updating Door Service...
IF /I %bit% == 1 (
XCOPY "%location%"\Resources\DoorService "C:\Program Files (x86)\Anytime Fitness\ClubHub DoorService" /Y
) ELSE ( XCOPY "%location%"\Resources\DoorService "C:\Program Files\Anytime Fitness\ClubHub DoorService" /Y)
)
ECHO Door Service update complete
ECHO ----
REM ==================================================================================================



REM ================ Installing Certificates for Club Hub client =========================
ECHO Installing client certificates...
ECHO Installing client certificates >> "C:\ClubHub\conversionLog.txt"
Resources\certmgr.exe /add /c Resources\ClubHubCert.cer /s /r localMachine TrustedPublisher
Resources\certmgr.exe /add /c Resources\ClubHubCert.cer /s /r localMachine root
ECHO ----
REM ======================================================================================

"%location%\Application\getDateTime.exe" >> "C:\ClubHub\conversionLog.txt"
ECHO Data Import Complete
ECHO Ready to launch Club Hub
ECHO Launching Club Hub UI installer >> "C:\ClubHub\conversionLog.txt"
Application\setupProduction.exe

IF DEFINED install ( net start "Anytime Fitness Door Service" )

REM ------------------ Set Firewall -----------------------------------------------
"%location%\Application\getDateTime.exe" >> "C:\ClubHub\conversionLog.txt"
ECHO Configuring Firewall...
ECHO Configuring Firewall >> "C:\ClubHub\conversionLog.txt"
netsh firewall add portopening TCP 13 "Club Hub TCP 13"
netsh firewall add portopening TCP 139 "Club Hub TCP 139"
netsh firewall add portopening TCP 9000 "Club Hub TCP 9000"
netsh firewall add portopening TCP 9090 "Club Hub TCP 9090"

netsh firewall add portopening UDP 123 "Club Hub UDP 123"
netsh firewall add portopening UDP 137 "Club Hub UDP 137"
netsh firewall add portopening UDP 138 "Club Hub UDP 138"

netsh firewall add portopening TCP 3306 "Door Service TCP 3306"
REM =================================================================================

REM ---------------------------- Delete Package Files -----------------------------------------
"%location%\Application\getDateTime.exe" >> "C:\ClubHub\conversionLog.txt"
ECHO Performing clean up operation...
ECHO Cleaning up package files >> "C:\ClubHub\conversionLog.txt"
DEL /F /Q "C:\ClubHub\ClubHubInstaller\Application"
DEL /F /Q "C:\ClubHub\ClubHubInstaller\ConsoleImporter"
DEL /F /Q "C:\ClubHub\ClubHubInstaller\Installer"
DEL /F /Q "C:\ClubHub\ClubHubInstaller\Resources"
DEL /F /Q "C:\ClubHub\ClubHubInstaller\Runtimes"
DEL /F /Q "C:\ClubHub\ClubHubInstaller\Antivirus Exclusion Directories.txt"
DEL /F /Q "C:\ClubHub\ClubHubInstaller\Installer.exe"
DEL /F /Q "C:\ClubHub\ClubHubInstaller\Start.txt"

REM ============================================================================================

"%location%\Application\getDateTime.exe" >> "C:\ClubHub\conversionLog.txt"
ECHO Club Hub Package Installer has completed >> "C:\ClubHub\conversionLog.txt"

EXIT
REM ========================================== END OF WINDOWS XP BATCH ===========================================================


:errorMessage
ECHO Aborting...
ECHO ---- >> "C:\ClubHub\conversionLog.txt"
ECHO Compatability Issue, Aborting Installation >> "C:\ClubHub\conversionLog.txt"
"%location%\Application\getDateTime.exe" >> "C:\ClubHub\conversionLog.txt"
exit


:noBatStart
ECHO Location: %location%
ECHO -- ERROR --
ECHO The Club Hub Installer Package cannot be run directly from this file
ECHO Plase exit and Run the Installer by clicking on the "Installer" application
ECHO ---- >> "C:\ClubHub\conversionLog.txt"
ECHO -- ERROR -- Attempted to run Instller from Batch file >> "C:\ClubHub\conversionLog.txt"
"%location%\Application\getDateTime.exe" >> "C:\ClubHub\conversionLog.txt"
PAUSE
exit



:quit
"%location%\Application\getDateTime.exe" >> "C:\ClubHub\conversionLog.txt"
ECHO The Club Hub Batch Installer has finished >> "C:\ClubHub\conversionLog.txt"
exit

